### 0.9.3

```{rubric} Features
```

* `neighbors` now works with `raft` and better supports approximate search with `cagra`, `ivfpq` and `ivfflat` {pr}`89` {smaller}`S Dicks`
* `spatial_autocorr` now works with sparse data matrices without densifying. It will use the sparse matrix by default. {pr}`93` {smaller}`S Dicks`

```{rubric} Bug fixes
```

* Fixes an issue where `pca` didn't write all parameters {pr}`91` {smaller}`S Dicks`
